summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorpgen <p.gen.progs@gmail.com>2023-02-20 22:23:32 +0100
committerpgen <p.gen.progs@gmail.com>2023-02-20 22:27:30 +0100
commit8a95715c3c48e3d0c772862c4b00db530634f1ed (patch)
tree0e16f446b5391b47709bc76a8bf66d3bce1d2449
parent668c0f96e22255c2b7797ff90a838b512d88e070 (diff)
Correct some comments and typos
-rw-r--r--smenu.c64
-rw-r--r--smenu.h4
2 files changed, 34 insertions, 34 deletions
diff --git a/smenu.h b/smenu.h
index 4394c0d..a758199 100644
--- a/smenu.h
+++ b/smenu.h
@@ -622,10 +622,10 @@ move_right(win_t * win, term_t * term, toggle_t * toggles,
long last_line, char * tmp_word);
int
-find_best_word_upward(long last_word, long s, long e);
+find_best_word_upwards(long last_word, long s, long e);
int
-find_best_word_downward(long last_word, long s, long e);
+find_best_word_downwards(long last_word, long s, long e);
void
move_up(win_t * win, term_t * term, toggle_t * toggles,
diff --git a/smenu.c b/smenu.c
index fb34e59..b14c354 100644
--- a/smenu.c
+++ b/smenu.c
@@ -4446,9 +4446,9 @@ select_starting_matches(win_t * win, term_t * term, search_data_t * search_data,
}
}
-/* ====================== */
-/* Moves the cursor left. */
-/* ====================== */
+/* ============================= */
+/* Moves the cursor to the left. */
+/* ============================= */
void
move_left(win_t * win, term_t * term, toggle_t * toggles,
search_data_t * search_data, langinfo_t * langinfo, long * nl,
@@ -4578,9 +4578,9 @@ shift_left(win_t * win, term_t * term, toggle_t * toggles,
last_line, tmp_word, langinfo);
}
-/* ======================= */
-/* Moves the cursor right. */
-/* ======================= */
+/* ============================== */
+/* Moves the cursor to the right. */
+/* ============================== */
void
move_right(win_t * win, term_t * term, toggle_t * toggles,
search_data_t * search_data, langinfo_t * langinfo, long * nl,
@@ -4677,10 +4677,10 @@ move_right(win_t * win, term_t * term, toggle_t * toggles,
term, last_line, tmp_word, langinfo);
}
-/* ============================================= */
-/* Shift content of the the window to the right. */
-/* Stop if the cursor will stop to be visible. */
-/* ============================================= */
+/* =========================================== */
+/* Shift content of the window to the right. */
+/* Stop if the cursor will stop to be visible. */
+/* ============================================*/
void
shift_right(win_t * win, term_t * term, toggle_t * toggles,
search_data_t * search_data, langinfo_t * langinfo, long * nl,
@@ -4756,13 +4756,13 @@ get_line_last_word(long line, long last_line)
/* ==================================================================== */
/* Try to locate the best word in the target line when trying to move */
/* the cursor upward. */
/* returns 1 if a word has been found else 0. */
/* This function has the side effect to potentially change the value of */
/* the variable 'current' if an adequate word is found. */
/* ==================================================================== */
int
-find_best_word_upward(long last_word, long s, long e)
+find_best_word_upwards(long last_word, long s, long e)
{
int found = 0;
long index;
@@ -4831,13 +4831,13 @@ find_best_word_upward(long last_word, long s, long e)
/* ==================================================================== */
/* Try to locate the best word in the target line when trying to move */
/* the cursor downward. */
/* returns 1 if a word has been found else 0. */
/* This function has the side effect to potentially change the value of */
/* the variable 'current' if an adequate word is found. */
/* ==================================================================== */
int
-find_best_word_downward(long last_word, long s, long e)
+find_best_word_downwards(long last_word, long s, long e)
{
int found = 0;
long index;
@@ -4909,9 +4909,9 @@ find_best_word_downward(long last_word, long s, long e)
return found;
}
/* ==================== */
/* Moves the cursor up. */
/* ==================== */
void
move_up(win_t * win, term_t * term, toggle_t * toggles,
search_data_t * search_data, langinfo_t * langinfo, long * nl,
@@ -4995,7 +4995,7 @@ move_up(win_t * win, term_t * term, toggle_t * toggles,
/* """""""""""""""""""""""""""""""""""""""""""""" */
line = first_selectable_line;
last_word = get_line_last_word(line, last_line);
- find_best_word_upward(last_word, s, e);
+ find_best_word_upwards(last_word, s, e);
}
else
{
@@ -5010,18 +5010,18 @@ move_up(win_t * win, term_t * term, toggle_t * toggles,
{
line = first_selectable_line;
last_word = get_line_last_word(line, last_line);
- find_best_word_upward(last_word, s, e);
+ find_best_word_upwards(last_word, s, e);
}
else
{
/* If this is not the case, search upward for the line with a */
/* selectable word. This line is guaranteed to exist. */
/* """""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
while (line >= first_selectable_line)
{
last_word = get_line_last_word(line, last_line);
- if (find_best_word_upward(last_word, s, e))
+ if (find_best_word_upwards(last_word, s, e))
{
found = 1;
break;
@@ -5072,9 +5072,9 @@ move_up(win_t * win, term_t * term, toggle_t * toggles,
last_line, tmp_word, langinfo);
}
/* ====================== */
/* Moves the cursor down. */
/* ====================== */
void
move_down(win_t * win, term_t * term, toggle_t * toggles,
search_data_t * search_data, langinfo_t * langinfo, long * nl,
@@ -5160,7 +5160,7 @@ move_down(win_t * win, term_t * term, toggle_t * toggles,
/* """"""""""""""""""""""""""""""""""""""""""""" */
line = last_selectable_line;
last_word = get_line_last_word(line, last_line);
- find_best_word_downward(last_word, s, e);
+ find_best_word_downwards(last_word, s, e);
}
else
{
@@ -5175,18 +5175,18 @@ move_down(win_t * win, term_t * term, toggle_t * toggles,
{
line = last_selectable_line;
last_word = get_line_last_word(line, last_line);
- find_best_word_downward(last_word, s, e);
+ find_best_word_downwards(last_word, s, e);
}
else
{
/* If this is not the case, search upward for the line with a */
/* selectable word. This line is guaranteed to exist. */
/* """""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
while (line <= last_selectable_line)
{
last_word = get_line_last_word(line, last_line);
- if (find_best_word_downward(last_word, s, e))
+ if (find_best_word_downwards(last_word, s, e))
{
found = 1;
break;
@@ -4756,13 +4756,13 @@ get_line_last_word(long line, long last_line)
/* ==================================================================== */
/* Try to locate the best word in the target line when trying to move */
-/* the cursor upward. */
+/* the cursor upwards. */
/* returns 1 if a word has been found else 0. */
/* This function has the side effect to potentially change the value of */
@@ -4831,13 +4831,13 @@ find_best_word_upward(long last_word, long s, long e)
/* ==================================================================== */
/* Try to locate the best word in the target line when trying to move */
-/* the cursor downward. */
+/* the cursor downwards. */
/* returns 1 if a word has been found else 0. */
/* This function has the side effect to potentially change the value of */
@@ -4909,9 +4909,9 @@ find_best_word_downward(long last_word, long s, long e)
return found;
}
-/* ==================== */
-/* Moves the cursor up. */
-/* ==================== */
+/* ========================= */
+/* Moves the cursor upwards. */
+/* ========================= */
void
move_up(win_t * win, term_t * term, toggle_t * toggles,
@@ -5010,18 +5010,18 @@ move_up(win_t * win, term_t * term, toggle_t * toggles,
else
{
- /* If this is not the case, search upward for the line with a */
- /* selectable word. This line is guaranteed to exist. */
- /* """""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
+ /* If this is not the case, search upwards for the line with a */
+ /* selectable word. This line is guaranteed to exist. */
+ /* """"""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
while (line >= first_selectable_line)
{
@@ -5072,9 +5072,9 @@ move_up(win_t * win, term_t * term, toggle_t * toggles,
last_line, tmp_word, langinfo);
}
-/* ====================== */
-/* Moves the cursor down. */
-/* ====================== */
+/* =========================== */
+/* Moves the cursor downwards. */
+/* =========================== */
void
move_down(win_t * win, term_t * term, toggle_t * toggles,
@@ -5175,18 +5175,18 @@ move_down(win_t * win, term_t * term, toggle_t * toggles,
else
{
- /* If this is not the case, search upward for the line with a */
- /* selectable word. This line is guaranteed to exist. */
- /* """""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
+ /* If this is not the case, search upwards for the line with a */
+ /* selectable word. This line is guaranteed to exist. */
+ /* """"""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
while (line <= last_selectable_line)
{